@@ -3,7 +3,7 @@ import tempfile
 import sys
 from subprocess import Popen, PIPE, call
 import os
-
+import shutil
 
 class MetaBin:
     def __repr__(self) :
@@ -39,9 +39,11 @@ class MetaBin:
         return 100*len(self.cogs)/self.new_completness
 
     @classmethod
-    def get_anis(cls, bins, outfile = None, method = "fastANI", block_size = 200, threads=1):
-
+    def get_anis(cls, bins, outfile = None, method = "fastANI", block_size = 500, threads=1):
         if method == "fastANI":
+            if not shutil.which('fastANI'):
+                print("You need fastANI if you do not provide a file with pairwise similarities, either install it or provide pairwise similarities (see doc...)", file = sys.stderr)
+                sys.exit(-1)
             fastani_file = tempfile.NamedTemporaryFile().name if outfile is None else outfile
 
             mags = [b.fnas for b in bins]
@@ -51,7 +53,7 @@ class MetaBin:
             if len(mag_blocks) > 1:
                 print("You have more then {bsize} bins, so we will run fastANI in blocks, if it crashes due to memory, make smaller blocks".format(bsize = block_size), file=sys.stderr)
 
-            with open(fastani_file, "a") as handle:
+            with open(fastani_file, "w") as handle:
                 handle.writelines(["query\tsubject\tani\tsize_q\tsize_s\n"])
 
             for i,bloc1 in enumerate(mag_blocks):
@@ -59,8 +61,9 @@ class MetaBin:
 
                 with open(b1_tfile, "w") as handle:
                     handle.writelines([l +"\n" for l in bloc1])
+
                 for j,bloc2 in enumerate(mag_blocks):
-                        print("doing bloc {i} and {j}".format(i = i, j=j))
+                        print("doing bloc {i} and {j}".format(i = i, j=j), file = sys.stderr)
                         b2_tfile = tempfile.NamedTemporaryFile().name
                         with open(b2_tfile, "w") as handle:
                             handle.writelines([l  +"\n" for l in bloc2])
@@ -68,18 +71,21 @@ class MetaBin:
                         out_tfile = tempfile.NamedTemporaryFile().name
                         call("fastANI --ql {b1} --rl {b2} -o {out} -t {threads} 2> /dev/null".format(b1 = b1_tfile, b2 = b2_tfile, out = out_tfile, threads = threads), shell = True)
                         with open(out_tfile) as handle:
-                            new_dat = ["\t".join([".".join(ll.split("/")[-1].split(".")[:-1]) if "." in ll else ll for ll in l.split()]) +"\n" for l in handle.readlines()]
+                            new_dat = ["\t".join([ll for ll in l.split()]) +"\n" for l in handle.readlines()]
                         with open(fastani_file, "a") as handle:
                             handle.writelines(new_dat)
 
                         os.remove(out_tfile)
                         os.remove(b2_tfile)
-                os.remove(b1_tfile)
-                with open(fastani_file) as handle:
-                    handle.readline()
-                    out_dists = {(l.split()[0], l.strip().split()[1]) : float(l.split()[2]) for l in handle}
-                if outfile is None:
-                    os.remove(fastani_file)
+
+            os.remove(b1_tfile)
+            with open(fastani_file) as handle:
+                handle.readline()
+                out_dists = {(l.split()[0], l.strip().split()[1]) : float(l.split()[2]) for l in handle}
+#                tfile = lambda k : ".".join(k.split(".")[:-1]) if (k.endswith(".fna") or k.endswith(".fa") or k.endswith(".fasta") or k.endswith(".fna") or k.endswith(".ffn")) else k
+#                out_dists = {(tfile(k[0]),tfile(k[1])) : v for k,v in out_dists.items()}
+            if outfile is None:
+                os.remove(fastani_file)
         else :
             print("No other method for ani computation implemented yet")
             sys.exit()
